==> jc-1.4.0.tar.gz: polyglot/visit/ExitChecker.h <==
// public class polyglot.visit.ExitChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c4ffacca45f5127f polyglot_visit_DataFlow
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 237ae12765b8ebe5 polyglot_visit_ExitChecker
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_DataFlow

#include "polyglot/visit/DataFlow.h"

#ifndef _JC_polyglot_visit_ExitChecker_H_
#define _JC_polyglot_visit_ExitChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_CodeDecl$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_DataFlow__24Item$object;
struct _jc_polyglot_visit_FlowGraph$object;

// Typedefs
typedef struct _jc_polyglot_visit_ExitChecker$sub_refs	_jc_polyglot_visit_ExitChecker$sub_refs;
typedef struct _jc_polyglot_visit_ExitChecker$sub_nonrefs	_jc_polyglot_visit_ExitChecker$sub_nonrefs;
typedef struct _jc_polyglot_visit_ExitChecker$refs	_jc_polyglot_visit_ExitChecker$refs;
typedef struct _jc_polyglot_visit_ExitChecker$nonrefs	_jc_polyglot_visit_ExitChecker$nonrefs;
typedef struct _jc_polyglot_visit_ExitChecker$object	_jc_polyglot_visit_ExitChecker$object;

typedef const struct _jc_polyglot_visit_ExitChecker$vmethods	_jc_polyglot_visit_ExitChecker$vmethods;
typedef const struct _jc_polyglot_visit_ExitChecker$vtable	_jc_polyglot_visit_ExitChecker$vtable;
typedef const struct _jc_polyglot_visit_ExitChecker$vtype	_jc_polyglot_visit_ExitChecker$vtype;

// Constructors
extern void _jc_polyglot_visit_ExitChecker$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_polyglot_visit_ExitChecker$method$check$3df37c60acd34b0e(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_object *);
extern struct _jc_polyglot_visit_DataFlow__24Item$object *_jc_polyglot_visit_ExitChecker$method$confluence$8f9f293f0bd8b7b5(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_polyglot_visit_DataFlow__24Item$object *_jc_polyglot_visit_ExitChecker$method$createInitialItem$1a8de5b116761d1a(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *);
extern struct _jc_object *_jc_polyglot_visit_ExitChecker$method$flow$98c03f38c33d1829(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_polyglot_visit_FlowGraph$object *_jc_polyglot_visit_ExitChecker$method$initGraph$1cd351c97638609f(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$check$3df37c60acd34b0e;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$confluence$8f9f293f0bd8b7b5;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$createInitialItem$1a8de5b116761d1a;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$flow$98c03f38c33d1829;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$initGraph$1cd351c97638609f;

// Virtual methods structure
struct _jc_polyglot_visit_ExitChecker$vmethods {
	void	(*check$3df37c60acd34b0e)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_object *);
	struct _jc_polyglot_visit_DataFlow__24Item$object	*(*confluence$8f9f293f0bd8b7b5)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_polyglot_visit_DataFlow__24Item$object	*(*createInitialItem$1a8de5b116761d1a)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *);
	struct _jc_object	*(*flow$98c03f38c33d1829)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_polyglot_visit_FlowGraph$object	*(*initGraph$1cd351c97638609f)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_visit_ExitChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_DataFlow$vmethods	polyglot_visit_DataFlow;
	_jc_polyglot_visit_ExitChecker$vmethods	polyglot_visit_ExitChecker;
};

// Vtype
struct _jc_polyglot_visit_ExitChecker$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ExitChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ExitChecker$sub_refs {
	struct _jc_object	*code;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ExitChecker$refs {
    _jc_polyglot_visit_ExitChecker$sub_refs	polyglot_visit_ExitChecker;
    _jc_polyglot_visit_DataFlow$sub_refs	polyglot_visit_DataFlow;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ExitChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ExitChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_DataFlow$sub_nonrefs	polyglot_visit_DataFlow;
    _jc_polyglot_visit_ExitChecker$sub_nonrefs	polyglot_visit_ExitChecker;
};

// Object instance structure
struct _jc_polyglot_visit_ExitChecker$object {
	_jc_polyglot_visit_ExitChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ExitChecker$vtype	*vtype;
	_jc_polyglot_visit_ExitChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ExitChecker$vtype _jc_polyglot_visit_ExitChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ExitChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ExitChecker$class_object;

#endif	/* _JC_polyglot_visit_ExitChecker_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/ExitChecker.h <==
// public class polyglot.visit.ExitChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c4ffacca45f5127f polyglot_visit_DataFlow
// @dep_class 8a4bd51bcd9d71a polyglot_visit_ErrorHandlingVisitor
// @dep_class 237ae12765b8ebe5 polyglot_visit_ExitChecker
// @dep_class 2f5b20d380322b22 polyglot_visit_HaltingVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_DataFlow

#include "polyglot/visit/DataFlow.h"

#ifndef _JC_polyglot_visit_ExitChecker_H_
#define _JC_polyglot_visit_ExitChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_CodeDecl$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_DataFlow__24Item$object;
struct _jc_polyglot_visit_FlowGraph$object;

// Typedefs
typedef struct _jc_polyglot_visit_ExitChecker$sub_refs	_jc_polyglot_visit_ExitChecker$sub_refs;
typedef struct _jc_polyglot_visit_ExitChecker$sub_nonrefs	_jc_polyglot_visit_ExitChecker$sub_nonrefs;
typedef struct _jc_polyglot_visit_ExitChecker$refs	_jc_polyglot_visit_ExitChecker$refs;
typedef struct _jc_polyglot_visit_ExitChecker$nonrefs	_jc_polyglot_visit_ExitChecker$nonrefs;
typedef struct _jc_polyglot_visit_ExitChecker$object	_jc_polyglot_visit_ExitChecker$object;

typedef const struct _jc_polyglot_visit_ExitChecker$vmethods	_jc_polyglot_visit_ExitChecker$vmethods;
typedef const struct _jc_polyglot_visit_ExitChecker$vtable	_jc_polyglot_visit_ExitChecker$vtable;
typedef const struct _jc_polyglot_visit_ExitChecker$vtype	_jc_polyglot_visit_ExitChecker$vtype;

// Constructors
extern void _jc_polyglot_visit_ExitChecker$method$_init$dac7f764f0e12933(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_visit_ExitChecker$method$check$3df37c60acd34b0e(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_DataFlow__24Item$object *_jc_polyglot_visit_ExitChecker$method$confluence$8f9f293f0bd8b7b5(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_DataFlow__24Item$object *_jc_polyglot_visit_ExitChecker$method$createInitialItem$1a8de5b116761d1a(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_ExitChecker$method$flow$98c03f38c33d1829(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_FlowGraph$object *_jc_polyglot_visit_ExitChecker$method$initGraph$1cd351c97638609f(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$check$3df37c60acd34b0e;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$confluence$8f9f293f0bd8b7b5;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$createInitialItem$1a8de5b116761d1a;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$flow$98c03f38c33d1829;
extern _jc_method _jc_polyglot_visit_ExitChecker$method_info$initGraph$1cd351c97638609f;

// Virtual methods structure
struct _jc_polyglot_visit_ExitChecker$vmethods {
	void	(*check$3df37c60acd34b0e)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_DataFlow__24Item$object	*(*confluence$8f9f293f0bd8b7b5)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_DataFlow__24Item$object	*(*createInitialItem$1a8de5b116761d1a)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_FlowGraph$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*flow$98c03f38c33d1829)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_polyglot_visit_DataFlow__24Item$object *, struct _jc_polyglot_visit_FlowGraph$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_FlowGraph$object	*(*initGraph$1cd351c97638609f)(_jc_env *, struct _jc_polyglot_visit_ExitChecker$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_ExitChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_HaltingVisitor$vmethods	polyglot_visit_HaltingVisitor;
	_jc_polyglot_visit_ErrorHandlingVisitor$vmethods	polyglot_visit_ErrorHandlingVisitor;
	_jc_polyglot_visit_DataFlow$vmethods	polyglot_visit_DataFlow;
	_jc_polyglot_visit_ExitChecker$vmethods	polyglot_visit_ExitChecker;
};

// Vtype
struct _jc_polyglot_visit_ExitChecker$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ExitChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ExitChecker$sub_refs {
	struct _jc_object	*code;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ExitChecker$refs {
    _jc_polyglot_visit_ExitChecker$sub_refs	polyglot_visit_ExitChecker;
    _jc_polyglot_visit_DataFlow$sub_refs	polyglot_visit_DataFlow;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_refs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_refs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ExitChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ExitChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_HaltingVisitor$sub_nonrefs	polyglot_visit_HaltingVisitor;
    _jc_polyglot_visit_ErrorHandlingVisitor$sub_nonrefs	polyglot_visit_ErrorHandlingVisitor;
    _jc_polyglot_visit_DataFlow$sub_nonrefs	polyglot_visit_DataFlow;
    _jc_polyglot_visit_ExitChecker$sub_nonrefs	polyglot_visit_ExitChecker;
};

// Object instance structure
struct _jc_polyglot_visit_ExitChecker$object {
	_jc_polyglot_visit_ExitChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ExitChecker$vtype	*vtype;
	_jc_polyglot_visit_ExitChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ExitChecker$vtype _jc_polyglot_visit_ExitChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ExitChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ExitChecker$class_object;

#endif	/* _JC_polyglot_visit_ExitChecker_H_ */
